package com.ruoyi.ems.controller;

import com.ruoyi.common.core.utils.poi.ExcelUtil;
import com.ruoyi.common.core.web.controller.BaseController;
import com.ruoyi.common.core.web.domain.AjaxResult;
import com.ruoyi.common.core.web.page.TableDataInfo;
import com.ruoyi.common.log.annotation.Log;
import com.ruoyi.common.log.enums.BusinessType;
import com.ruoyi.common.security.annotation.RequiresPermissions;
import com.ruoyi.ems.domain.AreaBuilding;
import com.ruoyi.ems.service.IAreaBuildingService;
import io.swagger.annotations.Api;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 建筑基本信息Controller
 *
 * @author ruoyi
 * @date 2024-07-09
 */
@RestController
@RequestMapping("/basecfg/area/building")
@Api(value = "AreaBuildingController", description = "建筑管理")
public class AreaBuildingController extends BaseController {
    @Autowired
    private IAreaBuildingService buildingService;

    /**
     * 查询建筑基本信息列表
     */
    @RequiresPermissions("basecfg:building:list")
    @GetMapping("/list")
    public TableDataInfo list(AreaBuilding areaBuilding) {
        startPage();
        List<AreaBuilding> list = buildingService.selectAreaBuildingList(areaBuilding);
        return getDataTable(list);
    }

    /**
     * 查询建筑基本信息列表
     */
    @RequiresPermissions("basecfg:building:list")
    @GetMapping("/listByArea")
    public AjaxResult listByArea(@RequestParam(name = "areaCode", required = false) String areaCode) {
        AreaBuilding param = new AreaBuilding();
        param.setAreaCode(areaCode);
        List<AreaBuilding> list = buildingService.selectAreaBuildingList(param);
        return success(list);
    }

    /**
     * 导出建筑基本信息列表
     */
    @RequiresPermissions("basecfg:building:export")
    @Log(title = "建筑基本信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, AreaBuilding areaBuilding) {
        List<AreaBuilding> list = buildingService.selectAreaBuildingList(areaBuilding);
        ExcelUtil<AreaBuilding> util = new ExcelUtil<AreaBuilding>(AreaBuilding.class);
        util.exportExcel(response, list, "建筑基本信息数据");
    }

    /**
     * 获取建筑基本信息详细信息
     */
    @RequiresPermissions("basecfg:building:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(buildingService.selectAreaBuildingById(id));
    }

    /**
     * 新增建筑基本信息
     */
    @RequiresPermissions("basecfg:building:add")
    @Log(title = "建筑基本信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody AreaBuilding areaBuilding) {
        return toAjax(buildingService.insertAreaBuilding(areaBuilding));
    }

    /**
     * 修改建筑基本信息
     */
    @RequiresPermissions("basecfg:building:edit")
    @Log(title = "建筑基本信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody AreaBuilding areaBuilding) {
        return toAjax(buildingService.updateAreaBuilding(areaBuilding));
    }

    /**
     * 删除建筑基本信息
     */
    @RequiresPermissions("basecfg:building:remove")
    @Log(title = "建筑基本信息", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(buildingService.deleteAreaBuildingByIds(ids));
    }
}
